@@ -1,18 +1,7 @@
 /* This file is part of the KDE project
-   Copyright (C) 2003 Alexander Kellett <lypanov@kde.org>
+   SPDX-FileCopyrightText: 2003 Alexander Kellett <lypanov@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License, or (at your option) version 3.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <http://www.gnu.org/licenses/>
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only
 */
 
 #ifndef FAVICONUPDATER_H
@@ -38,8 +27,6 @@ Q_SIGNALS:
     void done(bool succeeded, const QString &errorString);
 
 private Q_SLOTS:
-    void slotMimetype(KIO::Job *job, const QString &_type);
-    void slotFinished(KJob *job);
     void slotCanceled(const QString &errorString);
     void slotCompleted();
 
